SystemOrganization addCategory: #'Hipay-Core'!

Object subclass: #HPEnvironment
	instanceVariableNames: 'postURL userAccountId categoryId websiteId key'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Core'!

!HPEnvironment commentStamp: 'FrancoisStephany 1/29/2012 17:30' prior: 0!
HPEnvironment is the starting point for Hipay.
Here's an example of how to use it with Seaside:
	order := HPOrder new
		label: 'Test Order from localhost.';
		beAllAge;
		beEuro;
		yourself.
	order addItem: (HPOrderItem new
		name: 'The Seaside book';
		infos: 'This book contains all you need.';
		amount: 100;
		quantity: 3;
		categoryId: 564).
	order addItem: (HPOrderItem new
		name: 'The Moose ';
		infos: 'This book contains all you need to start with Moose.';
		amount: 25.1;
		quantity: 4;
		categoryId: 564).
		
	env := HPEnvironment new
		beTest;
		categoryId: '564';
		userAccountId: 'YOUR_ACCOUNT_ID';
		key: 'YOUR_FORM_B_SIGNING_KEY';
		websiteId: '3497';
		yourself.
	elements := env formElementsFor: order.
	
	html heading level: 1; with: 'HiPay !!'.
	html form
		action: (elements at: #url);
		with: [
			html hiddenInput 
				name: 'mode'; 
				value: (elements at: #mode).
			html hiddenInput
				name: 'website_id';
				value: (elements at: #websiteId).
			html hiddenInput
				name: 'sign';
				value: (elements at: #sign).
			html hiddenInput
				name: 'data';
				value: (elements at: #data).
				
			html submitButton.
	]!

!HPEnvironment methodsFor: 'helpers' stamp: 'FrancoisStephany 1/29/2012 15:00'!
beProduction
	self postURL: 'https://payment.hipay.com/index/form/'! !

!HPEnvironment methodsFor: 'helpers' stamp: 'FrancoisStephany 1/29/2012 15:00'!
beTest
	self postURL: 'https://test-payment.hipay.com/index/form/'! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:45'!
categoryId
	^ categoryId! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:45'!
categoryId: anObject
	categoryId := anObject! !

!HPEnvironment methodsFor: 'private' stamp: 'FrancoisStephany 1/29/2012 14:39'!
encodeXML: anXMLDocument
	^(Base64MimeConverter mimeEncode: anXMLDocument asString readStream multiLine: false) contents.! !

!HPEnvironment methodsFor: 'mode B form' stamp: 'FrancoisStephany 1/29/2012 15:02'!
formElementsFor: anHPOrder
	"returns a dictionary containing all the information to use with an Hipay form."
	| elements encodedData |
	anHPOrder setFieldsForEnvironment: self.
	
	encodedData := self encodeXML: anHPOrder generateXML.
	
	^Dictionary new
		at: #websiteId put: self websiteId;
		at: #mode put: 'MODE_B';
		at: #data put: encodedData;
		at: #sign put: (MD5 hashMessage: (encodedData , self key)) hex;
		at: #url put: self postURL;
		yourself.! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:42'!
key
	^ key! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:42'!
key: anObject
	key := anObject! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:42'!
postURL
	^ postURL! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:42'!
postURL: anObject
	postURL := anObject! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:42'!
userAccountId
	^ userAccountId! !

!HPEnvironment methodsFor: 'user credentials' stamp: 'FrancoisStephany 1/29/2012 14:42'!
userAccountId: anObject
	userAccountId := anObject! !

!HPEnvironment methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 15:06'!
websiteId
	^ websiteId! !

!HPEnvironment methodsFor: 'user credentials' stamp: 'FrancoisStephany 1/29/2012 15:06'!
websiteId: anObject
	websiteId := anObject! !

Object subclass: #HPXMLSerializable
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Core'!

HPXMLSerializable subclass: #HPOrder
	instanceVariableNames: 'items userAccountId currency label ageGroup categoryId urlAcquital urlOk urlKo urlCancel urlInstall urlLogo locale issuerAccountLogin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Core'!

!HPOrder methodsFor: 'items' stamp: 'FrancoisStephany 1/29/2012 12:40'!
addItem: anHPOrderItem
	self items add: anHPOrderItem.! !

!HPOrder methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 13:27'!
addItemsOn: root
	| itemsNode |
	self items isEmpty ifTrue: [ ^self ].
	itemsNode := XMLElement named: 'items'.
	
	self items doWithIndex: [:each :index |
		itemsNode addElement: (each generateXMLElementWithId: index)].
	
	root addElement: itemsNode.! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:05'!
ageGroup
	<collectForXML>
	^ ageGroup! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:26'!
ageGroup: anObject
	ageGroup := anObject! !

!HPOrder methodsFor: 'helpers' stamp: 'FrancoisStephany 1/29/2012 14:55'!
beAllAge
	self ageGroup: 'ALL'! !

!HPOrder methodsFor: 'helpers languages' stamp: 'FrancoisStephany 1/29/2012 14:58'!
beBelgianDutch
	self locale: 'nl_BE'! !

!HPOrder methodsFor: 'helpers languages' stamp: 'FrancoisStephany 1/29/2012 14:58'!
beBelgianFrench
	self locale: 'fr_BE'! !

!HPOrder methodsFor: 'helpers' stamp: 'FrancoisStephany 1/29/2012 14:54'!
beEuro
	self currency: 'EUR'! !

!HPOrder methodsFor: 'helpers languages' stamp: 'FrancoisStephany 1/29/2012 14:58'!
beFranceFrench
	self locale: 'fr_FR'! !

!HPOrder methodsFor: 'helpers languages' stamp: 'FrancoisStephany 1/29/2012 14:58'!
beUKEnglish
	self locale: 'en_GB'! !

!HPOrder methodsFor: 'helpers languages' stamp: 'FrancoisStephany 1/29/2012 14:58'!
beUSEnglish
	self locale: 'en_US'! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:05'!
categoryId
	<collectForXML>
	^ categoryId! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:26'!
categoryId: anObject
	categoryId := anObject! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:05'!
currency
	<collectForXML>
	^ currency! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:26'!
currency: anObject
	currency := anObject! !

!HPOrder methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 13:54'!
generateXML
	| document root |
	document := XMLDocument new
		version: '1.0';
		encoding: 'UTF-8';
		yourself.
	root := XMLElement named: 'order'.
	
	self addFieldsOn: root.
	self addItemsOn: root.

	document addElement: root.
	^document! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
issuerAccountLogin
	<collectForXML>
	^ issuerAccountLogin! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
issuerAccountLogin: anObject
	issuerAccountLogin := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:41'!
items
	" items in the order."
	^ items ifNil: [ items := OrderedCollection new ].! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
items: anObject
	items := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
label
	<collectForXML>
	^ label! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
label: anObject
	label := anObject! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:05'!
locale
	<collectForXML>
	^ locale! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:26'!
locale: anObject
	locale := anObject! !

!HPOrder methodsFor: 'helpers' stamp: 'FrancoisStephany 1/29/2012 14:45'!
setFieldsForEnvironment: anHPEnvironment
	self userAccountId: anHPEnvironment userAccountId.
	self categoryId: anHPEnvironment categoryId. ! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
urlAcquital
	<collectForXML>
	^ urlAcquital! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlAcquital: anObject
	urlAcquital := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
urlCancel
	<collectForXML>
	^ urlCancel! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlCancel: anObject
	urlCancel := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
urlInstall
	<collectForXML>
	^ urlInstall! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlInstall: anObject
	urlInstall := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
urlKo
	<collectForXML>
	^ urlKo! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlKo: anObject
	urlKo := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:13'!
urlLogo
	<collectForXML>
	^ urlLogo! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlLogo: anObject
	urlLogo := anObject! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:14'!
urlOk
	<collectForXML>
	^ urlOk! !

!HPOrder methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:26'!
urlOk: anObject
	urlOk := anObject! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:05'!
userAccountId
	<collectForXML>
	^ userAccountId! !

!HPOrder methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:26'!
userAccountId: anObject
	userAccountId := anObject! !

HPXMLSerializable subclass: #HPOrderItem
	instanceVariableNames: 'taxes name infos amount categoryId quantity reference'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Core'!

!HPOrderItem methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 14:13'!
addTaxesOn: aRootNote
	| taxesNode |
	self taxes isEmpty ifTrue: [ ^self ].
	
	taxesNode := XMLElement named: 'taxes'.
	self taxes doWithIndex: [:each :index |
		taxesNode addElement: (each generateXMLElementWithId: index)]! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 13:25'!
amount
	<collectForXML>
	^ amount! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:29'!
amount: anObject
	amount := anObject! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 13:25'!
categoryId
	<collectForXML>
	^ categoryId! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:29'!
categoryId: anObject
	categoryId := anObject! !

!HPOrderItem methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 16:39'!
generateXMLElementWithId: anId
	| node |
	node := XMLElement named: 'item'.
	node attributeAt: 'id' put: anId printString.
	self addFieldsOn: node.
	self addTaxesOn: node.
	^node! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 13:25'!
infos
	<collectForXML>
	^ infos! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:29'!
infos: anObject
	infos := anObject! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 13:26'!
name
	<collectForXML>
	^ name! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:29'!
name: anObject
	name := anObject! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 13:26'!
quantity
	<collectForXML>
	^ quantity! !

!HPOrderItem methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:29'!
quantity: anObject
	quantity := anObject! !

!HPOrderItem methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 13:25'!
reference
	<collectForXML>
	^ reference! !

!HPOrderItem methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:29'!
reference: anObject
	reference := anObject! !

!HPOrderItem methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 14:50'!
taxes
	^taxes ifNil: [ taxes := OrderedCollection new ]! !

!HPOrderItem methodsFor: 'accessing' stamp: 'FrancoisStephany 1/29/2012 12:31'!
taxes: aCollectionOfTaxes
	taxes := aCollectionOfTaxes! !

HPXMLSerializable subclass: #HPTax
	instanceVariableNames: 'id label amount'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Hipay-Core'!

!HPTax methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:09'!
amount
	<collectForXML>
	^ amount! !

!HPTax methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:31'!
amount: anObject
	amount := anObject! !

!HPTax methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 14:10'!
generateXMLElementWithId: anId
	| node |
	node := XMLElement named: 'tax'.
	node attributeAt: 'id' put: anId printString.
	self addFieldsOn: node.
	^node! !

!HPTax methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 14:09'!
label
	<collectForXML>
	^ label! !

!HPTax methodsFor: 'accessing mandatory' stamp: 'FrancoisStephany 1/29/2012 12:31'!
label: anObject
	label := anObject! !

!HPXMLSerializable methodsFor: 'xml generation' stamp: 'FrancoisStephany 1/29/2012 16:38'!
addFieldsOn: root
	"add all the fields with the pragma 'collectForXML''"
	(Pragma allNamed: #collectForXML in: self class) do: [ :each | | key value |
		key := each selector greaseString.
		value := self perform: each selector.
		value isNil ifFalse: [
			root addElement: ((XMLElement named: key) addContent: (XMLString string: value greaseString))
		]
	].! !
